@@ -28,7 +28,7 @@ class EdgeFunction(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-cloudfront.experimental.EdgeFunction",
 ):
-    '''(experimental) A Lambda@Edge function.
+    '''A Lambda@Edge function.
 
     Convenience resource for requesting a Lambda function in the 'us-east-1' region for use with Lambda@Edge.
     Implements several restrictions enforced by Lambda@Edge.
@@ -36,7 +36,6 @@ class EdgeFunction(
     Note that this construct requires that the 'us-east-1' region has been bootstrapped.
     See https://docs.aws.amazon.com/cdk/latest/guide/bootstrapping.html or 'cdk bootstrap --help' for options.
 
-    :stability: experimental
     :resource: AWS::Lambda::Function
     '''
 
@@ -85,7 +84,7 @@ class EdgeFunction(
         '''
         :param scope: -
         :param id: -
-        :param stack_id: (experimental) The stack ID of Lambda@Edge function. Default: - ``edge-lambda-stack-${region}``
+        :param stack_id: The stack ID of Lambda@Edge function. Default: - ``edge-lambda-stack-${region}``
         :param code: The source code of your Lambda function. You can point to a file in an Amazon Simple Storage Service (Amazon S3) bucket or specify your source code as inline text.
         :param handler: The name of the method within your code that Lambda calls to execute your function. The format includes the file name. It can also include namespaces and other qualifiers, depending on the runtime. For more information, see https://docs.aws.amazon.com/lambda/latest/dg/gettingstarted-features.html#gettingstarted-features-programmingmodel. Use ``Handler.FROM_IMAGE`` when defining a function from a Docker image. NOTE: If you specify your source code as inline text by specifying the ZipFile property within the Code property, specify index.function_name as the handler.
         :param runtime: The runtime environment for the Lambda function that you are uploading. For valid values, see the Runtime property in the AWS Lambda Developer Guide. Use ``Runtime.FROM_IMAGE`` when when defining a function from a Docker image.
@@ -121,8 +120,6 @@ class EdgeFunction(
         :param on_failure: The destination for failed invocations. Default: - no destination
         :param on_success: The destination for successful invocations. Default: - no destination
         :param retry_attempts: The maximum number of times to retry when the function returns an error. Minimum: 0 Maximum: 2 Default: 2
-
-        :stability: experimental
         '''
         props = EdgeFunctionProps(
             stack_id=stack_id,
@@ -178,7 +175,7 @@ class EdgeFunction(
         on_success: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
         retry_attempts: typing.Optional[jsii.Number] = None,
     ) -> aws_cdk.aws_lambda.Alias:
-        '''(experimental) Defines an alias for this version.
+        '''Defines an alias for this version.
 
         :param alias_name: -
         :param additional_versions: Additional versions with individual weights this alias points to. Individual additional version weights specified here should add up to (less than) one. All remaining weight is routed to the default version. For example, the config is Example:: version: "1" additionalVersions: [{ version: "2", weight: 0.05 }] Then 5% of traffic will be routed to function version 2, while the remaining 95% of traffic will be routed to function version 1. Default: No additional versions
@@ -188,8 +185,6 @@ class EdgeFunction(
         :param on_failure: The destination for failed invocations. Default: - no destination
         :param on_success: The destination for successful invocations. Default: - no destination
         :param retry_attempts: The maximum number of times to retry when the function returns an error. Minimum: 0 Maximum: 2 Default: 2
-
-        :stability: experimental
         '''
         options = aws_cdk.aws_lambda.AliasOptions(
             additional_versions=additional_versions,
@@ -205,11 +200,9 @@ class EdgeFunction(
 
     @jsii.member(jsii_name="addEventSource")
     def add_event_source(self, source: aws_cdk.aws_lambda.IEventSource) -> None:
-        '''(experimental) Adds an event source to this function.
+        '''Adds an event source to this function.
 
         :param source: -
-
-        :stability: experimental
         '''
         return typing.cast(None, jsii.invoke(self, "addEventSource", [source]))
 
@@ -233,7 +226,7 @@ class EdgeFunction(
         starting_position: typing.Optional[aws_cdk.aws_lambda.StartingPosition] = None,
         tumbling_window: typing.Optional[aws_cdk.core.Duration] = None,
     ) -> aws_cdk.aws_lambda.EventSourceMapping:
-        '''(experimental) Adds an event source that maps to this AWS Lambda function.
+        '''Adds an event source that maps to this AWS Lambda function.
 
         :param id: -
         :param batch_size: The largest number of records that AWS Lambda will retrieve from your event source at the time of invoking your function. Your function receives an event with all the retrieved records. Valid Range: Minimum value of 1. Maximum value of 10000. Default: - Amazon Kinesis, Amazon DynamoDB, and Amazon MSK is 100 records. Both the default and maximum for Amazon SQS are 10 messages.
@@ -250,8 +243,6 @@ class EdgeFunction(
         :param source_access_configurations: Specific settings like the authentication protocol or the VPC components to secure access to your event source. Default: - none
         :param starting_position: The position in the DynamoDB, Kinesis or MSK stream where AWS Lambda should start reading. Default: - Required for Amazon Kinesis, Amazon DynamoDB, and Amazon MSK Streams sources.
         :param tumbling_window: The size of the tumbling windows to group records sent to DynamoDB or Kinesis. Default: - None
-
-        :stability: experimental
         '''
         options = aws_cdk.aws_lambda.EventSourceMappingOptions(
             batch_size=batch_size,
@@ -284,7 +275,7 @@ class EdgeFunction(
         source_account: typing.Optional[builtins.str] = None,
         source_arn: typing.Optional[builtins.str] = None,
     ) -> None:
-        '''(experimental) Adds a permission to the Lambda resource policy.
+        '''Adds a permission to the Lambda resource policy.
 
         :param id: -
         :param principal: The entity for which you are granting permission to invoke the Lambda function. This entity can be any valid AWS service principal, such as s3.amazonaws.com or sns.amazonaws.com, or, if you are granting cross-account permission, an AWS account ID. For example, you might want to allow a custom application in another AWS account to push events to Lambda by invoking your function. The principal can be either an AccountPrincipal or a ServicePrincipal.
@@ -293,8 +284,6 @@ class EdgeFunction(
         :param scope: The scope to which the permission constructs be attached. The default is the Lambda function construct itself, but this would need to be different in cases such as cross-stack references where the Permissions would need to sit closer to the consumer of this permission (i.e., the caller). Default: - The instance of lambda.IFunction
         :param source_account: The AWS account ID (without hyphens) of the source owner. For example, if you specify an S3 bucket in the SourceArn property, this value is the bucket owner's account ID. You can use this property to ensure that all source principals are owned by a specific account.
         :param source_arn: The ARN of a resource that is invoking your function. When granting Amazon Simple Storage Service (Amazon S3) permission to invoke your function, specify this property with the bucket ARN as its value. This ensures that events generated only from the specified bucket, not just any bucket from any AWS account that creates a mapping to your function, can invoke the function.
-
-        :stability: experimental
         '''
         permission = aws_cdk.aws_lambda.Permission(
             principal=principal,
@@ -309,11 +298,9 @@ class EdgeFunction(
 
     @jsii.member(jsii_name="addToRolePolicy")
     def add_to_role_policy(self, statement: aws_cdk.aws_iam.PolicyStatement) -> None:
-        '''(experimental) Adds a statement to the IAM role assumed by the instance.
+        '''Adds a statement to the IAM role assumed by the instance.
 
         :param statement: -
-
-        :stability: experimental
         '''
         return typing.cast(None, jsii.invoke(self, "addToRolePolicy", [statement]))
 
@@ -326,14 +313,12 @@ class EdgeFunction(
         on_success: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
         retry_attempts: typing.Optional[jsii.Number] = None,
     ) -> None:
-        '''(experimental) Configures options for asynchronous invocation.
+        '''Configures options for asynchronous invocation.
 
         :param max_event_age: The maximum age of a request that Lambda sends to a function for processing. Minimum: 60 seconds Maximum: 6 hours Default: Duration.hours(6)
         :param on_failure: The destination for failed invocations. Default: - no destination
         :param on_success: The destination for successful invocations. Default: - no destination
         :param retry_attempts: The maximum number of times to retry when the function returns an error. Minimum: 0 Maximum: 2 Default: 2
-
-        :stability: experimental
         '''
         options = aws_cdk.aws_lambda.EventInvokeConfigOptions(
             max_event_age=max_event_age,
@@ -349,11 +334,9 @@ class EdgeFunction(
         self,
         identity: aws_cdk.aws_iam.IGrantable,
     ) -> aws_cdk.aws_iam.Grant:
-        '''(experimental) Grant the given identity permissions to invoke this Lambda.
+        '''Grant the given identity permissions to invoke this Lambda.
 
         :param identity: -
-
-        :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantInvoke", [identity]))
 
@@ -371,7 +354,7 @@ class EdgeFunction(
         statistic: typing.Optional[builtins.str] = None,
         unit: typing.Optional[aws_cdk.aws_cloudwatch.Unit] = None,
     ) -> aws_cdk.aws_cloudwatch.Metric:
-        '''(experimental) Return the given named metric for this Lambda Return the given named metric for this Function.
+        '''Return the given named metric for this Lambda Return the given named metric for this Function.
 
         Return the given named metric for this Lambda Return the given named metric for this Function.
 
@@ -384,8 +367,6 @@ class EdgeFunction(
         :param region: Region which this metric comes from. Default: - Deployment region.
         :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
         :param unit: Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream
-
-        :stability: experimental
         '''
         props = aws_cdk.aws_cloudwatch.MetricOptions(
             account=account,
@@ -413,7 +394,7 @@ class EdgeFunction(
         statistic: typing.Optional[builtins.str] = None,
         unit: typing.Optional[aws_cdk.aws_cloudwatch.Unit] = None,
     ) -> aws_cdk.aws_cloudwatch.Metric:
-        '''(experimental) Metric for the Duration of this Lambda How long execution of this Lambda takes.
+        '''Metric for the Duration of this Lambda How long execution of this Lambda takes.
 
         Average over 5 minutes
         Metric for the Duration of this Lambda How long execution of this Lambda takes.
@@ -428,8 +409,6 @@ class EdgeFunction(
         :param region: Region which this metric comes from. Default: - Deployment region.
         :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
         :param unit: Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream
-
-        :stability: experimental
         '''
         props = aws_cdk.aws_cloudwatch.MetricOptions(
             account=account,
@@ -457,7 +436,7 @@ class EdgeFunction(
         statistic: typing.Optional[builtins.str] = None,
         unit: typing.Optional[aws_cdk.aws_cloudwatch.Unit] = None,
     ) -> aws_cdk.aws_cloudwatch.Metric:
-        '''(experimental) How many invocations of this Lambda fail.
+        '''How many invocations of this Lambda fail.
 
         Sum over 5 minutes
 
@@ -469,8 +448,6 @@ class EdgeFunction(
         :param region: Region which this metric comes from. Default: - Deployment region.
         :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
         :param unit: Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream
-
-        :stability: experimental
         '''
         props = aws_cdk.aws_cloudwatch.MetricOptions(
             account=account,
@@ -498,7 +475,7 @@ class EdgeFunction(
         statistic: typing.Optional[builtins.str] = None,
         unit: typing.Optional[aws_cdk.aws_cloudwatch.Unit] = None,
     ) -> aws_cdk.aws_cloudwatch.Metric:
-        '''(experimental) Metric for the number of invocations of this Lambda How often this Lambda is invoked.
+        '''Metric for the number of invocations of this Lambda How often this Lambda is invoked.
 
         Sum over 5 minutes
         Metric for the number of invocations of this Lambda How often this Lambda is invoked.
@@ -513,8 +490,6 @@ class EdgeFunction(
         :param region: Region which this metric comes from. Default: - Deployment region.
         :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
         :param unit: Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream
-
-        :stability: experimental
         '''
         props = aws_cdk.aws_cloudwatch.MetricOptions(
             account=account,
@@ -542,7 +517,7 @@ class EdgeFunction(
         statistic: typing.Optional[builtins.str] = None,
         unit: typing.Optional[aws_cdk.aws_cloudwatch.Unit] = None,
     ) -> aws_cdk.aws_cloudwatch.Metric:
-        '''(experimental) Metric for the number of throttled invocations of this Lambda How often this Lambda is throttled.
+        '''Metric for the number of throttled invocations of this Lambda How often this Lambda is throttled.
 
         Sum over 5 minutes
         Metric for the number of throttled invocations of this Lambda How often this Lambda is throttled.
@@ -557,8 +532,6 @@ class EdgeFunction(
         :param region: Region which this metric comes from. Default: - Deployment region.
         :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
         :param unit: Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream
-
-        :stability: experimental
         '''
         props = aws_cdk.aws_cloudwatch.MetricOptions(
             account=account,
@@ -576,83 +549,61 @@ class EdgeFunction(
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="connections")
     def connections(self) -> aws_cdk.aws_ec2.Connections:
-        '''(experimental) Not supported.
+        '''Not supported.
 
         Connections are only applicable to VPC-enabled functions.
-
-        :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_ec2.Connections, jsii.get(self, "connections"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="currentVersion")
     def current_version(self) -> aws_cdk.aws_lambda.IVersion:
-        '''(experimental) Convenience method to make ``EdgeFunction`` conform to the same interface as ``Function``.
-
-        :stability: experimental
-        '''
+        '''Convenience method to make ``EdgeFunction`` conform to the same interface as ``Function``.'''
         return typing.cast(aws_cdk.aws_lambda.IVersion, jsii.get(self, "currentVersion"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="edgeArn")
     def edge_arn(self) -> builtins.str:
-        '''(experimental) The ARN of the version for Lambda@Edge.
-
-        :stability: experimental
-        '''
+        '''The ARN of the version for Lambda@Edge.'''
         return typing.cast(builtins.str, jsii.get(self, "edgeArn"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="functionArn")
     def function_arn(self) -> builtins.str:
-        '''(experimental) The ARN fo the function.
-
-        :stability: experimental
-        '''
+        '''The ARN fo the function.'''
         return typing.cast(builtins.str, jsii.get(self, "functionArn"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="functionName")
     def function_name(self) -> builtins.str:
-        '''(experimental) The name of the function.
-
-        :stability: experimental
-        '''
+        '''The name of the function.'''
         return typing.cast(builtins.str, jsii.get(self, "functionName"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="grantPrincipal")
     def grant_principal(self) -> aws_cdk.aws_iam.IPrincipal:
-        '''(experimental) The principal to grant permissions to.
-
-        :stability: experimental
-        '''
+        '''The principal to grant permissions to.'''
         return typing.cast(aws_cdk.aws_iam.IPrincipal, jsii.get(self, "grantPrincipal"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="isBoundToVpc")
     def is_bound_to_vpc(self) -> builtins.bool:
-        '''(experimental) Whether or not this Lambda function was bound to a VPC.
+        '''Whether or not this Lambda function was bound to a VPC.
 
         If this is is ``false``, trying to access the ``connections`` object will fail.
-
-        :stability: experimental
         '''
         return typing.cast(builtins.bool, jsii.get(self, "isBoundToVpc"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="lambda")
     def lambda_(self) -> aws_cdk.aws_lambda.IFunction:
-        '''(experimental) The underlying AWS Lambda function.
-
-        :stability: experimental
-        '''
+        '''The underlying AWS Lambda function.'''
         return typing.cast(aws_cdk.aws_lambda.IFunction, jsii.get(self, "lambda"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="latestVersion")
     def latest_version(self) -> aws_cdk.aws_lambda.IVersion:
-        '''(experimental) The ``$LATEST`` version of this function.
+        '''The ``$LATEST`` version of this function.
 
         Note that this is reference to a non-specific AWS Lambda version, which
         means the function this version refers to can return different results in
@@ -660,36 +611,25 @@ class EdgeFunction(
 
         To obtain a reference to an explicit version which references the current
         function configuration, use ``lambdaFunction.currentVersion`` instead.
-
-        :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_lambda.IVersion, jsii.get(self, "latestVersion"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="permissionsNode")
     def permissions_node(self) -> aws_cdk.core.ConstructNode:
-        '''(experimental) The construct node where permissions are attached.
-
-        :stability: experimental
-        '''
+        '''The construct node where permissions are attached.'''
         return typing.cast(aws_cdk.core.ConstructNode, jsii.get(self, "permissionsNode"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="version")
     def version(self) -> builtins.str:
-        '''(experimental) The most recently deployed version of this function.
-
-        :stability: experimental
-        '''
+        '''The most recently deployed version of this function.'''
         return typing.cast(builtins.str, jsii.get(self, "version"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="role")
     def role(self) -> typing.Optional[aws_cdk.aws_iam.IRole]:
-        '''(experimental) The IAM role associated with this function.
-
-        :stability: experimental
-        '''
+        '''The IAM role associated with this function.'''
         return typing.cast(typing.Optional[aws_cdk.aws_iam.IRole], jsii.get(self, "role"))
 
 
@@ -776,7 +716,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         runtime: aws_cdk.aws_lambda.Runtime,
         stack_id: typing.Optional[builtins.str] = None,
     ) -> None:
-        '''(experimental) Properties for creating a Lambda@Edge function.
+        '''Properties for creating a Lambda@Edge function.
 
         :param max_event_age: The maximum age of a request that Lambda sends to a function for processing. Minimum: 60 seconds Maximum: 6 hours Default: Duration.hours(6)
         :param on_failure: The destination for failed invocations. Default: - no destination
@@ -813,9 +753,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         :param code: The source code of your Lambda function. You can point to a file in an Amazon Simple Storage Service (Amazon S3) bucket or specify your source code as inline text.
         :param handler: The name of the method within your code that Lambda calls to execute your function. The format includes the file name. It can also include namespaces and other qualifiers, depending on the runtime. For more information, see https://docs.aws.amazon.com/lambda/latest/dg/gettingstarted-features.html#gettingstarted-features-programmingmodel. Use ``Handler.FROM_IMAGE`` when defining a function from a Docker image. NOTE: If you specify your source code as inline text by specifying the ZipFile property within the Code property, specify index.function_name as the handler.
         :param runtime: The runtime environment for the Lambda function that you are uploading. For valid values, see the Runtime property in the AWS Lambda Developer Guide. Use ``Runtime.FROM_IMAGE`` when when defining a function from a Docker image.
-        :param stack_id: (experimental) The stack ID of Lambda@Edge function. Default: - ``edge-lambda-stack-${region}``
-
-        :stability: experimental
+        :param stack_id: The stack ID of Lambda@Edge function. Default: - ``edge-lambda-stack-${region}``
         '''
         if isinstance(current_version_options, dict):
             current_version_options = aws_cdk.aws_lambda.VersionOptions(**current_version_options)
@@ -1329,11 +1267,9 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
 
     @builtins.property
     def stack_id(self) -> typing.Optional[builtins.str]:
-        '''(experimental) The stack ID of Lambda@Edge function.
+        '''The stack ID of Lambda@Edge function.
 
         :default: - ``edge-lambda-stack-${region}``
-
-        :stability: experimental
         '''
         result = self._values.get("stack_id")
         return typing.cast(typing.Optional[builtins.str], result)
